@@ -2,16 +2,16 @@ import json
 import urllib.request
 from base64 import b64decode
 
-import jwt
-import requests
-from django.conf import settings
+from cryptography import x509
+from cryptography.exceptions import InvalidSignature
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import hashes
+from cryptography.hazmat.primitives.asymmetric.padding import PKCS1v15
 from django.shortcuts import redirect
-from jwcrypto.jwt import JWK
-from M2Crypto import X509
-from M2Crypto.Err import M2CryptoError
 from rest_framework import response
+import requests
 
-from revpayment.models import RedirectState
+from revpayment.exceptions import InvalidCallback, HttpActionError
 from revpayment.settings import api_settings
 
 SNS_MESSAGE_TYPE_SUB_NOTIFICATION = "SubscriptionConfirmation"
@@ -86,14 +86,6 @@ class CheckoutSDK:
 
 
 def canonical_message_builder(content, format):
-    """Builds the canonical message to be verified.
-    Sorts the fields as a requirement from AWS
-    Args:
-        content (dict): Parsed body of the response
-        format (list): List of the fields that need to go into the message
-    Returns (str):
-        canonical message
-    """
     m = ""
 
     for field in sorted(format):
@@ -103,21 +95,10 @@ def canonical_message_builder(content, format):
             # Build with what you have
             pass
 
-    return str(m)
+    return m.encode()
 
 
 def verify_sns_notification(request):
-    """Takes a notification request from Amazon push service SNS and verifies the origin of the notification.
-    Kudos to Artur Rodrigues for suggesting M2Crypto: http://goo.gl/KAgPPc
-    Args:
-        request (HTTPRequest): The request object that is passed to the view function
-    Returns (bool):
-        True if he message passes the verification, False otherwise
-    Raises:
-        ValueError: If the body of the response couldn't be parsed
-        M2CryptoError: If an error raises during the verification process
-        URLError: If the SigningCertURL couldn't be opened
-    """
     cert = None
     pubkey = None
     canonical_message = None
@@ -139,7 +120,7 @@ def verify_sns_notification(request):
         "Type",
     ]
 
-    content = json.loads(request.body)
+    content = request.data
     decoded_signature = b64decode(content["Signature"])
 
     # Depending on the message type, canonical message format varies: http://goo.gl/oSrJl8
@@ -170,22 +151,38 @@ def verify_sns_notification(request):
         )
 
     # Load the certificate and extract the public key
-    cert = X509.load_cert_string(str(urllib.request(content["SigningCertURL"]).read()))
-    pubkey = cert.get_pubkey()
-    pubkey.reset_context(md="sha1")
-    pubkey.verify_init()
+    cert_string = urllib.request.urlopen(content["SigningCertURL"]).read()
 
-    # Feed the canonical message to sign it with the public key from the certificate
-    pubkey.verify_update(canonical_message)
-
-    # M2Crypto uses EVP_VerifyFinal() from openssl as the underlying verification function.
-    # http://goo.gl/Bk2G36: "EVP_VerifyFinal() returns 1 for a correct signature, 0 for failure and -1
-    # if some other error occurred."
-    verification_result = pubkey.verify_final(decoded_signature)
-
-    if verification_result == 1:
+    cert = x509.load_pem_x509_certificate(cert_string, default_backend())
+    pubkey: rsa.RSAPublicKey = cert.public_key()
+    try:
+        pubkey.verify(
+            decoded_signature,
+            canonical_message,
+            PKCS1v15(),
+            hashes.SHA1(),
+        )
         return True
-    elif verification_result == 0:
-        return False
+    except InvalidSignature:
+        raise InvalidCallback()
+
+
+def confirm_subcription(data):
+    if settings.STAGE == "prod":
+        host = api_settings.PAYMENT_HOST
     else:
-        raise M2CryptoError("Some error occured while verifying the signature.")
+        host = api_settings.PAYMENT_DEBUG_HOST
+
+    full_url = f"{host}/{api_settings.PAYMENT_VERSION}/subscription/confirm?client_id={settings.CLIENT_ID}&client_secret={settings.CLIENT_SECRET}"
+
+    try:
+        resp = requests.post(full_url, json={"token": data["Token"]})
+        resp.raise_for_status()
+        return resp.json()
+    except requests.HTTPError as exc:
+        err_resp = exc.response
+        if err_resp.status_code >= 500:
+            detail = "internal server error"
+        else:
+            detail = err_resp.json()["detail"]
+        raise HttpActionError(status_code=err_resp.status_code, detail=detail)
