@@ -28,5 +28,7 @@ class InvalidPaymentType(PaymentException):
 
 
 class InvalidCallback(PaymentException):
-    error = "invalid_callback"
-    error_detail = "signature in valid"
+    def __init__(self):
+        error = "invalid_callback"
+        error_detail = "signature in valid"
+        super().__init__(error_detail)
