@@ -1,9 +1,8 @@
 import json
 
-from django.conf import settings
 from django.utils import timezone
 
-from revpayment.actions import BaseAction, HttpAction
+from revpayment.actions import HttpAction
 from revpayment.invoice.exceptions import MapResultError
 from revpayment.settings import api_settings
 
@@ -146,7 +145,12 @@ class IssueAction(InvoiceAction):
 
 class EcpayIssue(IssueAction):
     invoice_type = "ecpay"
-    path = "/ecpay/invoice/issue"
+
+    @property
+    def path(self):
+        if self.category == "B2B":
+            return "/ecpay/B2B/invoice/issue"
+        return "/ecpay/B2C/invoice/issue"
 
     def map_result(self, data):
         payload = {}
