@@ -5,6 +5,7 @@ from revpayment.settings import api_settings
 default_app_config = "revpayment.logistics.apps.LogisticsConfig"
 
 
+
 class LogisticsSDK:
     def __init__(self, order=None, logistic_provider="ecpay"):
         self.order = order
@@ -24,6 +25,9 @@ class LogisticsSDK:
     def create_logistics(self, **kwargs):
         return self.provider.create_logistics(**kwargs)
 
+    def callback(self, *args, **kwargs):
+        return self.provider.callback(*args, **kwargs)
+
     def cvs_map(self, logistic_subtype, state, collection=False):
         return self.provider.cvs_map(logistic_subtype, collection, state)
 
